@@ -4,8 +4,7 @@ from scrapy.exceptions import DropItem
 import pika
 import os
 import json
-
-
+from scrapy_nc.queue.producer import Producer
 class AMQPPipeline(object):
     def __init__(self,
                  mq_dev_user,
@@ -18,10 +17,10 @@ class AMQPPipeline(object):
                  mq_prod_host,
                  mq_prod_port,
                  mq_prod_vhost):
-        self.parameters_dev = pika.URLParameters(f'amqp://{mq_dev_user}:{mq_dev_password}@{mq_dev_host}:{mq_dev_port}/{mq_dev_vhost}') if mq_dev_host else None
-        self.parameters_prod = pika.URLParameters(f'amqp://{mq_prod_user}:{mq_prod_password}@{mq_prod_host}:{mq_prod_port}/{mq_prod_vhost}') if mq_prod_host else None
-        self.queue_names_dev = []
-        self.queue_names_prod = []
+        self.producer_dev = Producer(
+            mq_dev_host, mq_dev_port, mq_dev_vhost, mq_dev_user, mq_dev_password)
+        self.producer_prod = Producer(
+            mq_prod_host, mq_prod_port, mq_prod_vhost, mq_prod_user, mq_prod_password)
 
     def process_item(self, item, spider):
         cralab_env = os.environ.get('CRAWLAB_ENV')
@@ -69,69 +68,27 @@ class AMQPPipeline(object):
                         "filename": item.get('oss_filename'),
                         "channel": spider.name,
                         "source_id": item.get('unique_id'),
+                        "url": item.get('url', default=''),
                     }, ensure_ascii=False)
 
                 if env == 'dev':
-                    if not self.channel_dev:
-                        continue
                     try:
-                        if not queue_name in self.queue_names_dev:
-                            self.channel_dev.queue_declare(queue_name,
-                                                           passive=False,
-                                                           durable=True,
-                                                           exclusive=False,
-                                                           auto_delete=False,
-                                                           arguments=None,
-                                                           )
-                            self.queue_names_dev.append(queue_name)
-                        spider.logger.info(f'declare queue {queue_name}')
-                        self.channel_dev.basic_publish('',
-                                                       queue_name,
-                                                       queue_data,
-                                                       pika.BasicProperties(
-                                                           content_type='application/json',
-                                                           delivery_mode=2),
-                                                       )
+                        self.producer_dev.publish(queue_name, queue_data)
                     except:
                         pass
                 else:
-                    if not self.channel_prod:
-                        continue
-                    if not queue_name in self.queue_names_prod:
-                        self.channel_prod.queue_declare(queue_name,
-                                                        passive=False,
-                                                        durable=True,
-                                                        exclusive=False,
-                                                        auto_delete=False,
-                                                        arguments=None,
-                                                        )
-                        self.queue_names_prod.append(queue_name)
-                    spider.logger.info(f'declare queue {queue_name}')
-                    self.channel_prod.basic_publish('',
-                                                    queue_name,
-                                                    queue_data,
-                                                    pika.BasicProperties(
-                                                        content_type='application/json',
-                                                        delivery_mode=2),
-                                                    )
-
+                    self.producer_prod.publish(queue_name, queue_data)
+                    spider.logger.info(f"send to amqp {queue_name} item: {item['unique_id']}, url: {item.get('url', default='')}")
         return item
 
     def open_spider(self, spider):
-        self.connection_dev = pika.BlockingConnection(
-            self.parameters_dev) if self.parameters_dev else None
-        self.connection_prod = pika.BlockingConnection(
-            self.parameters_prod) if self.parameters_prod else None
-        spider.logger.info(f'connect amqp success')
-        self.channel_dev = self.connection_dev.channel() if self.connection_dev else None
-        self.channel_prod = self.connection_prod.channel() if self.connection_prod else None
+        self.producer_dev.connect()
+        self.producer_prod.connect()
         spider.logger.info(f'create channel success')
 
     def close_spider(self, spider):
-        if self.channel_dev:
-            self.channel_dev.close()
-        if self.channel_prod:
-            self.channel_prod.close()
+        self.producer_dev.close()
+        self.producer_prod.close()
         spider.logger.info(f'close connection success')
 
     @classmethod
