@@ -27,10 +27,7 @@ class OSSPipeline(object):
             'Content-Type': 'application/json',
         })
         spider.logger.info(
-            f'upload data to oss: {oss_filename}, status: {result.status}')
-        # 存完 oss 后如果有 html ，清空
-        if item.get('html'):
-            item['html'] = None
+            f"upload data to oss: {oss_filename}, url: {item.get('url', default='')}, status: {result.status}")
         return item
 
     def open_spider(self, spider):
